==> onos-yang-runtime-2.2.0-b5-sources.jar: org/onosproject/yang/gen/v1/l3vpnsvcext/rev20160730/l3vpnsvcext/l3vpnsvc/sites/site/sitenetworkaccesses/sitenetworkaccess/vpnattachment/DefaultAugmentedL3VpnVpnAttachment.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.l3vpnsvc.sites.site.sitenetworkaccesses.sitenetworkaccess.vpnattachment;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.rdrtprofile.SiteRole;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedL3VpnVpnAttachment.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedL3VpnVpnAttachment extends InnerModelObject implements AugmentedL3VpnVpnAttachment {
    protected SiteRole siteRole;

    @Override
    public SiteRole siteRole() {
        return siteRole;
    }

    @Override
    public void siteRole(SiteRole siteRole) {
        this.siteRole = siteRole;
    }

    @Override
    public int hashCode() {
        return Objects.hash(siteRole);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedL3VpnVpnAttachment) {
            DefaultAugmentedL3VpnVpnAttachment other = (DefaultAugmentedL3VpnVpnAttachment) obj;
            return
                Objects.equals(siteRole, other.siteRole);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("siteRole=" + siteRole)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedL3VpnVpnAttachment.
     */
    public DefaultAugmentedL3VpnVpnAttachment() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/l3vpnsvcext/rev20160730/l3vpnsvcext/l3vpnsvc/sites/site/sitenetworkaccesses/sitenetworkaccess/vpnattachment/DefaultAugmentedL3VpnVpnAttachment.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.l3vpnsvc.sites.site.sitenetworkaccesses.sitenetworkaccess.vpnattachment;

import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.l3vpnsvcext.rev20160730.l3vpnsvcext.rdrtprofile.SiteRole;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedL3VpnVpnAttachment.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedL3VpnVpnAttachment extends InnerModelObject implements AugmentedL3VpnVpnAttachment {
    protected SiteRole siteRole;

    @Override
    public SiteRole siteRole() {
        return siteRole;
    }

    @Override
    public void siteRole(SiteRole siteRole) {
        this.siteRole = siteRole;
    }

    @Override
    public int hashCode() {
        return Objects.hash(siteRole);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedL3VpnVpnAttachment) {
            DefaultAugmentedL3VpnVpnAttachment other = (DefaultAugmentedL3VpnVpnAttachment) obj;
            return
                Objects.deepEquals(siteRole, other.siteRole);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("siteRole=" + siteRole)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedL3VpnVpnAttachment.
     */
    public DefaultAugmentedL3VpnVpnAttachment() {
    }

}
